@@ -24,15 +24,6 @@ AnalogMeterWidget::AnalogMeterWidget(QWidget *parent) : VolumeMeterWidget(parent
 }
 
 void AnalogMeterWidget::draw(QPainter *painter){
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(background == NULL){
         drawBackground();
     }
@@ -57,15 +48,6 @@ void AnalogMeterWidget::draw(QPainter *painter){
 }
 
 void AnalogMeterWidget::drawBackground(){
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(background != NULL){
         delete background;
         background = NULL;
@@ -166,15 +148,6 @@ void AnalogMeterWidget::drawBackground(){
 void AnalogMeterWidget::initPainter(QPainter *painter){
     painter->setRenderHint(QPainter::Antialiasing, true);
 
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     painter->setViewport(0, 0, w, h);
 
     painter->setWindow(-0.5 * w, -3.4 * h, w, h);
