@@ -26,15 +26,6 @@ HorizontalVolumeBarWidget::HorizontalVolumeBarWidget(QWidget *parent) : VolumeMe
 void HorizontalVolumeBarWidget::draw(QPainter *painter){
     float vol;
 
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(dbUnit){
         vol = ((float) currentValue) / MAX_DB;
     }else{
@@ -54,15 +45,6 @@ void HorizontalVolumeBarWidget::draw(QPainter *painter){
 }
 
 void HorizontalVolumeBarWidget::drawBackground(){
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(background != NULL){
         delete background;
         background = NULL;
