@@ -28,15 +28,6 @@ VolumeLineChartWidget::VolumeLineChartWidget(QWidget *parent) : VolumeMeterWidge
 void VolumeLineChartWidget::draw(QPainter *painter){
     float vol;
 
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(dbUnit){
         vol = ((float) currentValue) / MAX_DB;
     }else{
@@ -67,15 +58,6 @@ void VolumeLineChartWidget::draw(QPainter *painter){
 }
 
 void VolumeLineChartWidget::drawBackground(){
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
-
     if(background != NULL){
         delete background;
         background = NULL;
@@ -145,14 +127,7 @@ void VolumeLineChartWidget::drawBackground(){
 }
 
 void VolumeLineChartWidget::initValues(){
-    float h = height();
-    float w = width();
-
-    if(w > (RATIO * h)){
-        w = RATIO * h;
-    }else{
-        h = w / RATIO;
-    }
+    calculateSize();
 
     for(int i = 0; i < (2.7 * h / 2.); i++){
         volumeValues->append(0.);
