@@ -31,13 +31,14 @@ class VolumeLineChartWidget : public VolumeMeterWidget
 public:
     VolumeLineChartWidget(QWidget *parent);
 
-    void draw(QPainter *painter);
     void setDbUnit(bool b);
 
 protected:
-    void paintEvent(QPaintEvent *event);
+    void draw(QPainter *painter);
+    void resizeEvent(QResizeEvent *event);
 
 private:
+    void drawBackground();
     void initValues();
 
     QList<float> *volumeValues;
