@@ -30,17 +30,19 @@ VolumeMeterWidget::VolumeMeterWidget(QWidget *parent) :
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 }
 
-void VolumeMeterWidget::initPainter(QPainter *painter){
-    painter->setRenderHint(QPainter::Antialiasing, true);
-
-    float h = height();
-    float w = width();
+void VolumeMeterWidget::calculateSize(){
+    h = height();
+    w = width();
 
     if(w > (RATIO * h)){
         w = RATIO * h;
     }else{
         h = w / RATIO;
     }
+}
+
+void VolumeMeterWidget::initPainter(QPainter *painter){
+    painter->setRenderHint(QPainter::Antialiasing, true);
 
     painter->setViewport(0, 0, w, h);
     painter->setWindow(0, 0, w, h);
@@ -53,6 +55,8 @@ void VolumeMeterWidget::mouseReleaseEvent(QMouseEvent */*event*/){
 void VolumeMeterWidget::paintEvent(QPaintEvent */*event*/){
     QPainter painter(this);
 
+    calculateSize();
+
     initPainter(& painter);
 
     draw(& painter);
