@@ -44,7 +44,10 @@ protected:
     QImage *background;
     int currentValue;
     bool dbUnit;
+    float h;
+    float w;
 
+    virtual void calculateSize();
     virtual void draw(QPainter *painter) = 0;
     virtual void initPainter(QPainter *painter);
     void mouseReleaseEvent(QMouseEvent *);
